/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.gluten.sql.shims

import org.apache.spark.internal.Logging

/** Provider interface for matching and retrieving the Shims of a specific Spark version */
trait SparkShimProvider extends Logging {
  def matches(version: String): Boolean = {
    val expectedDescRuntime = SparkShimDescriptor(version)
    val matches = SparkShimDescriptor.DESCRIPTOR.matches(expectedDescRuntime)
    if (matches && SparkShimDescriptor.DESCRIPTOR != expectedDescRuntime) {
      logWarning(
        s"Spark runtime version $version is not matched with Gluten's fully" +
          s" tested version ${SparkShimDescriptor.DESCRIPTOR.toString()}")
    }
    matches
  }

  def createShim: SparkShims
}
